@@ -679,7 +679,7 @@ class CleanGraph:
         self.G = G
         self.config = config
         self.in_mat_raw = nx.to_numpy_array(G)
-        logger.info("Preprocessing -- Filling any NaN, Inf, and diagonal with 0...")
+        logger.debug("Preprocessing -- Filling any NaN, Inf, and diagonal with 0...")
         self.in_mat = self._autofix(self.in_mat_raw)
 
     @staticmethod
@@ -1201,6 +1201,7 @@ def create_subgraph(
 
     subgraph_nodes = set()
 
+    # Handle the node subset
     if node_subset:
         existing_nodes = [node for node in node_subset if source_graph.has_node(node)]
         missing_nodes = set(node_subset) - set(existing_nodes)
@@ -1215,7 +1216,15 @@ def create_subgraph(
 
     valid_edges = []
 
-    if edge_subset:
+    # handle the edge subset
+    if edge_subset is None:
+        # include all edges between the specified nodes
+        subgraph = source_graph.subgraph(node_subset).copy()
+    elif len(edge_subset) == 0:
+        # include only the specified nodes with no edges
+        subgraph = nx.Graph()
+        subgraph.add_nodes_from(node_subset)
+    else:
         for edge in edge_subset:
             if len(edge) == 2:  # case for standard Graph with (u, v)
                 u, v = edge
@@ -1260,6 +1269,10 @@ def create_subgraph(
 
     subgraph = source_graph.subgraph(subgraph_nodes).copy()
 
+    # remove all edges if edge_subset is empty (i.e., no edges should be included)
+    if edge_subset == []:
+        subgraph.remove_edges_from(list(subgraph.edges()))
+
     if edge_subset:
         subgraph.remove_edges_from(list(subgraph.edges()))
         subgraph.add_edges_from(valid_edges)
